#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.features.renderer import IRenderedContent
from zope.annotation.interfaces import IAttributeAnnotatable
from zope.container.interfaces import IOrderedContainer
from zope.contentprovider.interfaces import IContentProvider

# import packages
from pyams_i18n.schema import I18nTextLineField
from zope.container.constraints import containers, contains
from zope.interface import Interface, Attribute
from zope.schema import Bool, List, Choice, Set

from pyams_content import _


PARAGRAPH_CONTAINER_KEY = 'pyams_content.paragraph'


class IBaseParagraph(IRenderedContent, IAttributeAnnotatable):
    """Base paragraph interface"""

    containers('.IParagraphContainer')

    icon_class = Attribute("Icon class in paragraphs list")
    icon_hint = Attribute("Icon hint in paragraphs list")

    visible = Bool(title=_("Visible?"),
                   description=_("Is this paragraph visible in front-office?"),
                   required=True,
                   default=True)

    title = I18nTextLineField(title=_("§ Title"),
                              required=False)


class IParagraphContainer(IOrderedContainer):
    """Paragraphs container"""

    contains(IBaseParagraph)

    def append(self, value):
        """Add given value to container"""


class IParagraphContainerTarget(IAttributeAnnotatable):
    """Paragraphs container marker interface"""


class IParagraphFactory(Interface):
    """Paragraph factory utility interface"""

    name = Attribute("Factory name")
    content_type = Attribute("Factory content type")
    custom_menu = Attribute("Display factory in 'custom' paragraphs menu")


class IParagraphFactorySettings(Interface):
    """Paragraph factory settings interface

    This interface is used to defined default auto-created paragraphs
    for a given shared tool."""

    allowed_paragraphs = Set(title=_("Allowed paragraphs"),
                             description=_("List of paragraphs allowed for this content type"),
                             required=False,
                             value_type=Choice(vocabulary='PyAMS paragraph factories'))

    auto_created_paragraphs = List(title=_("Default paragraphs"),
                                   description=_("List of paragraphs automatically added to a new content"),
                                   required=False,
                                   value_type=Choice(vocabulary='PyAMS paragraph factories'))


class IParagraphRenderer(IContentProvider):
    """Paragraph renderer interface"""

    language = Attribute("Preview language")
